

#include "pref-classes.h"


// --------------------------------------------------------------------------------------------------------------------------------
// From here from VS
// --------------------------------------------------------------------------------------------------------------------------------

  
list<int> get_transitive_reduction(ppref p, int& ntuples);
  
